import { h } from 'vue'
import store from '@/store'

const { statusOptions } = store.dictStore.globalDicts || {}
const select = {
  type: 'selection',
  width: '50',
  reserveSelection: true
}
export const allColumn = [
  {
    label: '序号',
    type: 'index',
    width: '60'
  },
  {
    label: '项目名称',
    key: 'projectName',
    prop: 'projectName',
    minWidth: '200',
    showOverflowTooltip: true
  },
  {
    label: '申报单位',
    key: 'buildOrg',
    prop: 'buildOrg',
    minWidth: '200',
    showOverflowTooltip: true
  },
  {
    label: '项目类型',
    key: 'projectTypeName',
    prop: 'projectTypeName',
    width: 80
  },
  {
    label: '项目申报资金(万元)',
    key: 'declaredAmount',
    prop: 'declaredAmount',
    width: '150'
  },
  {
    label: '项目批复资金(万元)',
    key: 'approvalAmount',
    prop: 'approvalAmount',
    width: '150'
  },
  {
    label: '预算年度',
    key: 'projectYear',
    prop: 'projectYear',
    width: '80'
  },
  {
    label: '是否开启方案申报',
    key: 'isStartDeclaredProject',
    prop: 'isStartDeclaredProject',
    width: '140',
    render: row => h('span', row.isStartDeclaredProject ? '是' : '否')
  },
  {
    label: '项目状态',
    key: 'status',
    prop: 'status',
    width: '180',
    render: row => [
      h('span', {
        class: ['dot mr-4', `bg-${statusOptions[row.status]?.color}`]
      }),
      h(
        'span',
        {
          class: `text-${statusOptions[row.status]?.color}`
        },
        row.status && statusOptions[row.stage]?.name + '-' + statusOptions[row.status]?.name
      )
    ]
  },
  {
    label: '创建时间',
    key: 'createOn',
    prop: 'createOn',
    width: '180'
  },
  {
    label: '操作',
    slot: 'action',
    width: '120',
    fixed: 'right'
  }
]
export const buildColumn = [
  select,
  {
    label: '序号',
    type: 'index',
    width: '60'
  },
  {
    label: '项目名称',
    key: 'projectName',
    prop: 'projectName',
    minWidth: '200',
    showOverflowTooltip: true
  },
  {
    label: '申报单位',
    key: 'buildOrg',
    prop: 'buildOrg',
    minWidth: '200',
    showOverflowTooltip: true
  },
  {
    label: '项目类型',
    key: 'projectTypeName',
    prop: 'projectTypeName',
    width: 80
  },
  {
    label: '项目申报资金(万元)',
    key: 'declaredAmount',
    prop: 'declaredAmount',
    width: '150'
  },
  {
    label: '项目批复资金(万元)',
    key: 'approvalAmount',
    prop: 'approvalAmount',
    width: '150'
  },
  {
    label: '预算年度',
    key: 'projectYear',
    prop: 'projectYear',
    width: '80'
  },
  {
    label: '是否开启方案申报',
    key: 'isStartDeclaredProject',
    prop: 'isStartDeclaredProject',
    width: '140',
    render: row => h('span', row.isStartDeclaredProject ? '是' : '否')
  },
  {
    label: '项目状态',
    key: 'status',
    prop: 'status',
    width: '180',
    render: row => [
      h('span', {
        class: ['dot mr-4', `bg-${statusOptions[row.status]?.color}`]
      }),
      h(
        'span',
        {
          class: `text-${statusOptions[row.status]?.color}`
        },
        row.status && statusOptions[row.stage]?.name + '-' + statusOptions[row.status]?.name
      )
    ]
  },
  {
    label: '创建时间',
    key: 'createOn',
    prop: 'createOn',
    width: '180'
  },
  {
    label: '操作',
    slot: 'action',
    width: '180',
    fixed: 'right'
  }
]

export const maintenanceColumn = [
  select,
  {
    label: '序号',
    type: 'index',
    width: '60'

  },
  {
    label: '项目名称',
    key: 'projectName',
    prop: 'projectName',
    minWidth: '200',
    showOverflowTooltip: true
  },
  {
    label: '申报单位',
    key: 'buildOrg',
    prop: 'buildOrg',
    minWidth: '200',
    showOverflowTooltip: true
  },
  {
    label: '项目类型',
    key: 'projectTypeName',
    prop: 'projectTypeName',
    width: 80
  },
  {
    label: '运维包',
    key: 'operationPackageName',
    prop: 'operationPackageName',
    width: '150'
  },
  {
    label: '项目申报资金(万元)',
    key: 'declaredAmount',
    prop: 'declaredAmount',
    width: '150'
  },
  {
    label: '项目批复资金(万元)',
    key: 'approvalAmount',
    prop: 'approvalAmount',
    width: '150'
  },
  {
    label: '预算年度',
    key: 'projectYear',
    prop: 'projectYear',
    width: '80'
  },
  {
    label: '是否开启方案申报',
    key: 'isStartDeclaredProject',
    prop: 'isStartDeclaredProject',
    width: '140',
    render: row => h('span', row.isStartDeclaredProject ? '是' : '否')
  },
  {
    label: '项目状态',
    key: 'status',
    prop: 'status',
    width: '180',
    render: row => [
      h('span', {
        class: ['dot mr-4', `bg-${statusOptions[row.status]?.color}`]
      }),
      h(
        'span',
        {
          class: `text-${statusOptions[row.status]?.color}`
        },
        row.status && statusOptions[row.stage]?.name + '-' + statusOptions[row.status]?.name
      )
    ]
  },
  {
    label: '创建时间',
    key: 'createOn',
    prop: 'createOn',
    width: '180'
  },
  {
    label: '操作',
    slot: 'action',
    width: '150',
    fixed: 'right'
  }
]

export const columnType = {
  '00': allColumn,
  '01': buildColumn,
  '02': maintenanceColumn,
  '03': allColumn
}
